=begin comment

Fastly API

Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/) 

The version of the API Spec document: 1.0.0
Contact: oss@fastly.com

=end comment

=cut

#
# NOTE: This class is auto generated.
# Do not edit the class manually.
#
package WebService::Fastly::Object::RateLimiter;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON::MaybeXS qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use WebService::Fastly::Object::RateLimiterResponse1;

use base ("Class::Accessor", "Class::Data::Inheritable");

#
#
#
# NOTE: This class is auto generated. Do not edit the class manually.
#

=begin comment

Fastly API

Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/) 

The version of the API Spec document: 1.0.0
Contact: oss@fastly.com

=end comment

=cut

#
# NOTE: This class is auto generated.
# Do not edit the class manually.
#
__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('openapi_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {});
__PACKAGE__->mk_classdata('class_documentation' => {});
__PACKAGE__->mk_classdata('openapi_nullable' => {});

# new plain object
sub new {
    my ($class, %args) = @_;

    my $self = bless {}, $class;

    $self->init(%args);

    return $self;
}

# initialize the object
sub init
{
    my ($self, %args) = @_;

    foreach my $attribute (keys %{$self->attribute_map}) {
        my $args_key = $self->attribute_map->{$attribute};
        $self->$attribute( $args{ $args_key } );
    }
}

# return perl hash
sub to_hash {
    my $self = shift;
    my $_hash = decode_json(JSON()->new->allow_blessed->convert_blessed->encode($self));

    return $_hash;
}

# used by JSON for serialization
sub TO_JSON {
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
    }

    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use openapi_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->openapi_types} ) {
        my $_json_attribute = $self->attribute_map->{$_key};
        my $_is_nullable = ($self->openapi_nullable->{$_key} || 'false') eq 'true';
        if ($_type =~ /^array\[(.+)\]$/i) { # array
            my $_subclass = $1;
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element, $_is_nullable);
            }
            $self->{$_key} = \@_array;
        } elsif ($_type =~ /^hash\[string,(.+)\]$/i) { # hash
            my $_subclass = $1;
            my %_hash = ();
            while (my($_key, $_element) = each %{$hash->{$_json_attribute}}) {
                $_hash{$_key} = $self->_deserialize($_subclass, $_element, $_is_nullable);
            }
            $self->{$_key} = \%_hash;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute}, $_is_nullable);
        } else {
            $log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data, $is_nullable) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if (!(defined $data) && $is_nullable) {
        return undef;
    }
    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "WebService::Fastly::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '',
                                  class => 'RateLimiter',
                                  required => [], # TODO
}                                 );

__PACKAGE__->method_documentation({
    'name' => {
        datatype => 'string',
        base_name => 'name',
        description => 'A human readable name for the rate limiting rule.',
        format => '',
        read_only => 'false',
            },
    'uri_dictionary_name' => {
        datatype => 'string',
        base_name => 'uri_dictionary_name',
        description => 'The name of an Edge Dictionary containing URIs as keys. If not defined or &#x60;null&#x60;, all origin URIs will be rate limited.',
        format => '',
        read_only => 'false',
            },
    'http_methods' => {
        datatype => 'ARRAY[string]',
        base_name => 'http_methods',
        description => 'Array of HTTP methods to apply rate limiting to.',
        format => '',
        read_only => 'false',
            },
    'rps_limit' => {
        datatype => 'int',
        base_name => 'rps_limit',
        description => 'Upper limit of requests per second allowed by the rate limiter.',
        format => '',
        read_only => 'false',
            },
    'window_size' => {
        datatype => 'int',
        base_name => 'window_size',
        description => 'Number of seconds during which the RPS limit must be exceeded in order to trigger a violation.',
        format => '',
        read_only => 'false',
            },
    'client_key' => {
        datatype => 'ARRAY[string]',
        base_name => 'client_key',
        description => 'Array of VCL variables used to generate a counter key to identify a client. Example variables include &#x60;req.http.Fastly-Client-IP&#x60;, &#x60;req.http.User-Agent&#x60;, or a custom header like &#x60;req.http.API-Key&#x60;.',
        format => '',
        read_only => 'false',
            },
    'penalty_box_duration' => {
        datatype => 'int',
        base_name => 'penalty_box_duration',
        description => 'Length of time in minutes that the rate limiter is in effect after the initial violation is detected.',
        format => '',
        read_only => 'false',
            },
    'action' => {
        datatype => 'string',
        base_name => 'action',
        description => 'The action to take when a rate limiter violation is detected.',
        format => '',
        read_only => 'false',
            },
    'response' => {
        datatype => 'RateLimiterResponse1',
        base_name => 'response',
        description => '',
        format => '',
        read_only => 'false',
            },
    'response_object_name' => {
        datatype => 'string',
        base_name => 'response_object_name',
        description => 'Name of existing response object. Required if &#x60;action&#x60; is &#x60;response_object&#x60;. Note that the rate limiter response is only updated to reflect the response object content when saving the rate limiter configuration.',
        format => '',
        read_only => 'false',
            },
    'logger_type' => {
        datatype => 'string',
        base_name => 'logger_type',
        description => 'Name of the type of logging endpoint to be used when action is &#x60;log_only&#x60;. The logging endpoint type is used to determine the appropriate log format to use when emitting log entries.',
        format => '',
        read_only => 'false',
            },
    'feature_revision' => {
        datatype => 'int',
        base_name => 'feature_revision',
        description => 'Revision number of the rate limiting feature implementation. Defaults to the most recent revision.',
        format => '',
        read_only => 'false',
            },
});

__PACKAGE__->openapi_types( {
    'name' => 'string',
    'uri_dictionary_name' => 'string',
    'http_methods' => 'ARRAY[string]',
    'rps_limit' => 'int',
    'window_size' => 'int',
    'client_key' => 'ARRAY[string]',
    'penalty_box_duration' => 'int',
    'action' => 'string',
    'response' => 'RateLimiterResponse1',
    'response_object_name' => 'string',
    'logger_type' => 'string',
    'feature_revision' => 'int'
} );

__PACKAGE__->attribute_map( {
    'name' => 'name',
    'uri_dictionary_name' => 'uri_dictionary_name',
    'http_methods' => 'http_methods',
    'rps_limit' => 'rps_limit',
    'window_size' => 'window_size',
    'client_key' => 'client_key',
    'penalty_box_duration' => 'penalty_box_duration',
    'action' => 'action',
    'response' => 'response',
    'response_object_name' => 'response_object_name',
    'logger_type' => 'logger_type',
    'feature_revision' => 'feature_revision'
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});

__PACKAGE__->openapi_nullable( {
    'uri_dictionary_name' => 'true',
    'response' => 'true',
    'response_object_name' => 'true',
} );


1;
